@@ -8,7 +8,7 @@ class builder(object):
     def __init__(
         self, args, images_out_dir, img_file, definition_file_path, tag, cwd, **kwargs
     ):
-        self.__format = kwargs.get("format", "docker")
+        self.__format = args.format
         self.__args = args
         self.__images_out_dir = images_out_dir
         self.__img_file = img_file
@@ -25,12 +25,13 @@ class builder(object):
     def build_singularity(self):
         sif_file = f"{self.__images_out_dir}/{self.__img_file}.sif"
         subprocess.run(
-            f"sudo `which singularity` build --force {sif_file}"
+            f"sudo `which singularity` build --force {sif_file} "
             f"{self.__definition_file_path}",
             shell=True,
             check=True,
         )
-        subprocess.run(f"sudo chown $USER:$USER {sif_file}", shell=True, check=True)
+        subprocess.run(f"sudo chown $USER {sif_file}", shell=True, check=True)
+        print(f"Built Singularity image file: {sif_file}")
         # TODO: adapt this
         exit(0)
 
@@ -54,14 +55,20 @@ class builder(object):
             self.image_file = f"{self.__images_out_dir}/{self.__args.sif_file}"
         else:
             self.image_file = f"{image_base_name}.sif"
-        if self.__args.convert and (
-            not os.path.exists(self.image_file) or self.__args.force
-        ):
-            subprocess.run(
-                f"cd {self.__cwd} && singularity build --force {self.image_file} docker-daemon:{self.__tag}",
-                shell=True,
-                check=True,
-            )
+        if self.__args.convert:
+            if (
+                not os.path.exists(self.image_file)
+                or self.__args.force
+                or self.__args.sif_file
+            ):
+                subprocess.run(
+                    f"cd {self.__cwd} && singularity build --force {self.image_file} docker-daemon:{self.__tag}",
+                    shell=True,
+                    check=True,
+                )
+                print(f"Built Singularity image file: {self.image_file}")
+            else:
+                print(f"Already existing Singularity image file: {self.image_file}")
 
         if self.__args.enroot_file:
             self.image_file = f"{self.__images_out_dir}/{self.__args.enroot_file}"
